diff --git a/src/wp-includes/pluggable.php b/src/wp-includes/pluggable.php
index b398e5fe54..6a07dbca42 100644
--- a/src/wp-includes/pluggable.php
+++ b/src/wp-includes/pluggable.php
@@ -2690,6 +2690,8 @@ if ( ! function_exists( 'wp_text_diff' ) ) :
 	 *      title.
 	 * 'title_right' : Default is an empty string. Change the HTML to the right of
 	 *      the title.
+	 * 'show_split_view' : Default is an empty string. Show the HTML in split view to the right of
+	 *      the title and Left of the title.
 	 *
 	 * @since 2.6.0
 	 *
@@ -2699,7 +2701,7 @@ if ( ! function_exists( 'wp_text_diff' ) ) :
 	 *
 	 * @param string       $left_string  "old" (left) version of string
 	 * @param string       $right_string "new" (right) version of string
 	 * @param string|array $args         Optional. Change 'title', 'title_left', and 'title_right' defaults.
 	 * @return string Empty string if strings are equivalent or HTML with differences.
 	 */
 	function wp_text_diff( $left_string, $right_string, $args = null ) {
@@ -2707,6 +2709,7 @@ if ( ! function_exists( 'wp_text_diff' ) ) :
 			'title'       => '',
 			'title_left'  => '',
 			'title_right' => '',
+			'show_split_view' => '',
 		);
 		$args     = wp_parse_args( $args, $defaults );
 
@@ -2699,7 +2701,7 @@ if ( ! function_exists( 'wp_text_diff' ) ) :
 	 * @param string       $left_string  "old" (left) version of string
 	 * @param string       $right_string "new" (right) version of string
-	 * @param string|array $args         Optional. Change 'title', 'title_left', and 'title_right' defaults.
+	 * @param string|array $args         Optional. Change 'title', 'title_left', title_right and 'show_split_view' defaults.
 	 * @return string Empty string if strings are equivalent or HTML with differences.
 	 */
